@@ -192,8 +192,9 @@ class ClassifyFiles(object):
                 pass
             X = tf.keras.utils.img_to_array(im)
             return tf.reshape(X,[X.shape[0]//size,size,size,3])
-        
-        model = load_model("classification")
+            
+        print(os.getcwd())
+        model = load_model("./PdfInfoExtractor/classification")
         return self.decoder[self.model.predict(preprocess(img_path)).argmax()]
     
     def classify_left_over_imgs(self):
